%bcond_without pgm
%bcond_without unwind

Name:           zeromq
Version:        4.3.5
Release:        %autorelease
Summary:        Software library for fast, message-based applications

License:        MPLv2.0 AND BSD-3-Clause AND MIT
URL:            https://zeromq.org
Source0:        https://github.com/%{name}/libzmq/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  libsodium-devel
BuildRequires:  gnutls-devel

%if %{with unwind}
BuildRequires:  libunwind-devel
%endif

%if %{with pgm}
BuildRequires:  openpgm-devel
BuildRequires:  krb5-devel
%endif

# https://github.com/zeromq/libzmq/pull/4609 - Upgrade of CMake files
Patch0:         zeromq-fix-cmake-warnings.patch

%description
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the ZeroMQ shared library.


%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}


%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        doc
Summary:        HTML documentation for the %{name} library
BuildArch:      noarch

%description    doc
This package contains HTML pages for %{name}.

%prep
%autosetup -p1

# Remove bundled code.
rm -rf external/wepoll

# Fix permissions.
chmod -x src/xsub.hpp


%build
%cmake
#cmake -DENABLE_CURVE:BOOL=ON -DWITH_LIBSODIUM:BOOL=ON -DWITH_OPENPGM:BOOL=ON ..

%cmake_build

%install
%cmake_install

# Doc
mv -f %{buildroot}/usr/doc/zmq %{buildroot}%{_docdir}/

# Manual pages
install -d %{buildroot}%{_mandir}/{man3,man7}
install -pm 0644 doc/*.3 %{buildroot}%{_mandir}/man3/
install -pm 0644 doc/*.7 %{buildroot}%{_mandir}/man7/

# Static library
rm -f %{buildroot}%{_libdir}/libzmq.a

# Unused binaries
rm -f %{buildroot}%{_bindir}/{inproc_lat,inproc_thr,local_lat,local_thr,proxy_thr,remote_lat,remote_thr}

%check
%ifnarch s390x
%ctest
%endif
%ifarch s390x
make check V=1 || ( cat test-suite.log && exit 1 )
%endif

%files
%doc README.md AUTHORS NEWS
%license LICENSE
#%%{_bindir}/curve_keygen
%{_libdir}/libzmq.so.5*
%{_mandir}/man3/zmq_*
%{_mandir}/man7/zmq_*
%{_mandir}/man7/zmq.*

%files devel
%{_libdir}/libzmq.so
%{_libdir}/pkgconfig/libzmq.pc
%{_includedir}/zmq*.h
%{_libdir}/cmake/ZeroMQ/

%files doc
%{_docdir}/zmq/

%changelog
%autochangelog

